@@ -1,5 +1,7 @@
 import unittest
 
+from sklearn import base
+
 from gbm_autosplit import lgbm
 from . import utils
 
@@ -28,3 +30,11 @@ class TestLGBM(unittest.TestCase):
         instance_attribute_keys = model.__dict__.keys()
         get_params_keys = model.get_params().keys()
         self.assertSetEqual(set(get_params_keys) - set(instance_attribute_keys), set([]))
+
+    def test_clone_cl(self):
+        model = lgbm.LGBMClassifier()
+        base.clone(model)
+
+    def test_clone_rg(self):
+        model = lgbm.LGBMRegressor()
+        base.clone(model)
